package com.huashe.park.core.service;


import com.huashe.park.domain.entity.BdDevcTrailUwb;

import java.util.List;
import java.util.Map;

/**
 * 室内坐标定位Service接口
 *
 * @author ruoyi
 * @date 2024-10-16
 */
public interface IBdDevcTrailUwbService {
    /**
     * 查询室内坐标定位
     *
     * @param id 室内坐标定位主键
     * @return 室内坐标定位
     */
    public BdDevcTrailUwb selectBdDevcTrailUwbById(Long id);

    /**
     * 查询室内坐标定位列表
     *
     * @param bdDevcTrailUwb 室内坐标定位
     * @return 室内坐标定位集合
     */
    public List<BdDevcTrailUwb> selectBdDevcTrailUwbList(BdDevcTrailUwb bdDevcTrailUwb);

    /**
     * 新增室内坐标定位
     *
     * @param bdDevcTrailUwb 室内坐标定位
     * @return 结果
     */
    public int insertBdDevcTrailUwb(BdDevcTrailUwb bdDevcTrailUwb);

    /**
     * 修改室内坐标定位
     *
     * @param bdDevcTrailUwb 室内坐标定位
     * @return 结果
     */
    public int updateBdDevcTrailUwb(BdDevcTrailUwb bdDevcTrailUwb);

    /**
     * 批量删除室内坐标定位
     *
     * @param ids 需要删除的室内坐标定位主键集合
     * @return 结果
     */
    public int deleteBdDevcTrailUwbByIds(Long[] ids);

    /**
     * 删除室内坐标定位信息
     *
     * @param id 室内坐标定位主键
     * @return 结果
     */
    public int deleteBdDevcTrailUwbById(Long id);

    public void saveUwbTrail();

    public Map uwbOAuth();


}
